summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:31:30 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:31:30 +0000
commit50a68acd45f1790d1eccc3fc0284428239f0a842 (patch)
treeb27b722ba988bf524ffc7be2ad9d3b2e00a81f95 /sys
parent08592383ac26c24f6ccbe6ecc419c378e5616454 (diff)
use splnet instead of splimp
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/mvme68k/dev/if_ie.c16
-rw-r--r--sys/arch/mvme68k/dev/if_le.c6
2 files changed, 11 insertions, 11 deletions
diff --git a/sys/arch/mvme68k/dev/if_le.c b/sys/arch/mvme68k/dev/if_le.c
index 159be94d94e..0ab0e9edd6e 100644
--- a/sys/arch/mvme68k/dev/if_le.c
+++ b/sys/arch/mvme68k/dev/if_le.c
@@ -1,4 +1,4 @@
-/* $Id: if_le.c,v 1.2 1995/11/07 08:49:02 deraadt Exp $ */
+/* $Id: if_le.c,v 1.3 1995/12/27 22:31:29 deraadt Exp $ */
/*-
* Copyright (c) 1982, 1992, 1993
@@ -420,7 +420,7 @@ leinit(unit)
register int s;
if ((ifp->if_flags & IFF_RUNNING) == 0) {
- s = splimp();
+ s = splnet();
ifp->if_flags |= IFF_RUNNING;
lereset(&sc->sc_dev);
lestart(ifp);
@@ -819,7 +819,7 @@ leioctl(ifp, cmd, data)
register struct ifaddr *ifa;
register struct le_softc *sc = lecd.cd_devs[ifp->if_unit];
register struct lereg1 *ler1;
- int s = splimp(), error = 0;
+ int s = splnet(), error = 0;
switch (cmd) {
diff --git a/sys/arch/mvme68k/dev/if_ie.c b/sys/arch/mvme68k/dev/if_ie.c
index f39b56090ff..a1993ed86b0 100644
--- a/sys/arch/mvme68k/dev/if_ie.c
+++ b/sys/arch/mvme68k/dev/if_ie.c
@@ -1,4 +1,4 @@
-/* $Id: if_ie.c,v 1.2 1995/11/07 08:49:00 deraadt Exp $ */
+/* $Id: if_ie.c,v 1.3 1995/12/27 22:31:25 deraadt Exp $ */
/*-
* Copyright (c) 1995 Theo de Raadt
@@ -90,7 +90,7 @@ Mode of operation:
shall have the I (IE_CMD_INTR) bit set in the command. This way,
when an interrupt arrives at ieintr(), it is immediately possible
to tell what precisely caused it. ANY OTHER command-sending
- routines should run at splimp(), and should post an acknowledgement
+ routines should run at splnet(), and should post an acknowledgement
to every interrupt they generate.
*/
@@ -1347,7 +1347,7 @@ ie_setupram(sc)
volatile struct ie_sys_ctl_block *scb;
int s;
- s = splimp();
+ s = splnet();
iscp = sc->iscp;
(sc->memzero)((char *) iscp, sizeof *iscp);
@@ -1381,7 +1381,7 @@ void
iereset(sc)
struct ie_softc *sc;
{
- int s = splimp();
+ int s = splnet();
printf("%s: reset\n", sc->sc_dev.dv_xname);
@@ -1450,7 +1450,7 @@ command_and_wait(sc, cmd, pcmd, mask)
/*
* XXX
* I don't think this timeout works on suns.
* we are at splimp() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1688,7 +1688,7 @@ setup_bufs(sc)
/*
* Run the multicast setup command.
- * Called at splimp().
+ * Called at splnet().
*/
static int
mc_setup(sc, ptr)
@@ -1723,7 +1723,7 @@ mc_setup(sc, ptr)
* includes executing the CONFIGURE, IA-SETUP, and MC-SETUP commands, starting
* the receiver unit, and clearing interrupts.
*
* THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
*/
int
ieinit(sc)
@@ -1825,7 +1825,7 @@ ieioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch(cmd) {
@@ -1450,7 +1450,7 @@ command_and_wait(sc, cmd, pcmd, mask)
* XXX
* I don't think this timeout works on suns.
- * we are at splimp() in the loop, and the timeout
+ * we are at splnet() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1723,7 +1723,7 @@ mc_setup(sc, ptr)
* the receiver unit, and clearing interrupts.
*
- * THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
+ * THIS ROUTINE MUST BE CALLED AT splnet() OR HIGHER.
*/
int